# Public domain

import argparse
import zlib

parser = argparse.ArgumentParser(description="Compute file CRCs.")
parser.add_argument("files", metavar="FILE", type=str, nargs="+", help="file to digest")

cmdargs = parser.parse_args()

def crc32(file_path):
    """
    Compute file crc32 digest.

    args:
      file_path String: absolute or relative path to file.

    Returns:
      string: CRC as hex, like "60E39E64".

    Raises an OSError when file cannot be opened.
    """
    with open(file_path, "rb") as f:
        prev = 0
        while True:
            data = f.read(4096)
            if not data:
                break
            prev = zlib.crc32(data, prev)

        return "%X" % (prev & 0xFFFFFFFF)

for file_path in cmdargs.files:
    try:
        crc = crc32(file_path)
        print(crc, file_path)
    except OSError:
        print("ERR: could not open %s" % file_path)

input("Press enter to continue...")

